@@ -30,8 +30,8 @@ EBImoran.mc <- function (n, x, listw, nsim, zero.policy = FALSE,
         stop("Check of data and weights ID integrity failed")
     if (spChk && !chkIDs(n, listw)) 
         stop("Check of data and weights ID integrity failed")
-    if (nsim > gamma(m + 1)) 
-        stop("nsim too large for this number of observations")
+    gamres <- suppressWarnings(nsim > gamma(m + 1))
+    if (gamres) stop("nsim too large for this number of observations")
     if (nsim < 1) stop ("nsim too small")
     S0 <- Szero(listw)
     EB <- EBest(n, x)
