@@ -108,7 +108,8 @@ moran.mc <- function(x, listw, nsim, zero.policy=FALSE,
 	}
 	n <- length(listw$neighbours)
 	if (n != length(x)) stop("objects of different length")
-	if (nsim > gamma(n+1)) stop("nsim too large for this n")
+        gamres <- suppressWarnings(nsim > gamma(n + 1))
+        if (gamres) stop("nsim too large for this number of observations")
 	if (nsim < 1) stop("nsim too small")
 	
 	S0 <- Szero(listw)
@@ -143,4 +144,3 @@ moran.mc <- function(x, listw, nsim, zero.policy=FALSE,
 	lres
 }
 
-
